summaryrefslogtreecommitdiffstats
path: root/qt-models/divetripmodel.h
diff options
context:
space:
mode:
Diffstat (limited to 'qt-models/divetripmodel.h')
-rw-r--r--qt-models/divetripmodel.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/qt-models/divetripmodel.h b/qt-models/divetripmodel.h
index 8ff4524b3..6d34d30bb 100644
--- a/qt-models/divetripmodel.h
+++ b/qt-models/divetripmodel.h
@@ -104,7 +104,7 @@ private:
int findTripIdx(const dive_trip *trip) const;
int findDiveIdx(const dive *d) const; // Find _top_level_ dive
int findDiveInTrip(int tripIdx, const dive *d) const; // Find dive inside trip. Second parameter is index of trip
- int findInsertionIndex(timestamp_t when) const; // Where to insert item with timestamp "when"
+ int findInsertionIndex(const dive_trip *trip) const; // Where to insert trip
// Access trip and dive data
static QVariant diveData(const struct dive *d, int column, int role);